@@ -23,7 +23,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -43,15 +43,21 @@ G_BEGIN_DECLS
 
 /**
  * GtkAssistantPageType:
- * @GTK_ASSISTANT_PAGE_CONTENT: The page has regular contents.
+ * @GTK_ASSISTANT_PAGE_CONTENT: The page has regular contents. Both the
+ *  Back and forward buttons will be shown.
  * @GTK_ASSISTANT_PAGE_INTRO: The page contains an introduction to the
- *  assistant task.
+ *  assistant task. Only the Forward button will be shown if there is a
+ *   next page.
  * @GTK_ASSISTANT_PAGE_CONFIRM: The page lets the user confirm or deny the
- *  changes.
+ *  changes. The Back and Apply buttons will be shown.
  * @GTK_ASSISTANT_PAGE_SUMMARY: The page informs the user of the changes
- *  done.
+ *  done. Only the Close button will be shown.
  * @GTK_ASSISTANT_PAGE_PROGRESS: Used for tasks that take a long time to
  *  complete, blocks the assistant until the page is marked as complete.
+ *   Only the back button will be shown.
+ * @GTK_ASSISTANT_PAGE_CUSTOM: Used for when other page types are not
+ *  appropriate. No buttons will be shown, and the application must
+ *  add its own buttons through gtk_assistant_add_action_widget().
  *
  * An enum for determining the page role inside the #GtkAssistant. It's
  * used to handle buttons sensitivity and visibility.
@@ -59,6 +65,9 @@ G_BEGIN_DECLS
  * Note that an assistant needs to end its page flow with a page of type
  * %GTK_ASSISTANT_PAGE_CONFIRM, %GTK_ASSISTANT_PAGE_SUMMARY or
  * %GTK_ASSISTANT_PAGE_PROGRESS to be correct.
+ *
+ * The Cancel button will only be shown if the page isn't "committed".
+ * See gtk_assistant_commit() for details.
  */
 typedef enum
 {
@@ -66,7 +75,8 @@ typedef enum
   GTK_ASSISTANT_PAGE_INTRO,
   GTK_ASSISTANT_PAGE_CONFIRM,
   GTK_ASSISTANT_PAGE_SUMMARY,
-  GTK_ASSISTANT_PAGE_PROGRESS
+  GTK_ASSISTANT_PAGE_PROGRESS,
+  GTK_ASSISTANT_PAGE_CUSTOM
 } GtkAssistantPageType;
 
 typedef struct _GtkAssistant        GtkAssistant;
@@ -77,15 +87,8 @@ struct _GtkAssistant
 {
   GtkWindow  parent;
 
-  GtkWidget *GSEAL (cancel);
-  GtkWidget *GSEAL (forward);
-  GtkWidget *GSEAL (back);
-  GtkWidget *GSEAL (apply);
-  GtkWidget *GSEAL (close);
-  GtkWidget *GSEAL (last);
-
   /*< private >*/
-  GtkAssistantPrivate *GSEAL (priv);
+  GtkAssistantPrivate *priv;
 };
 
 struct _GtkAssistantClass
@@ -108,7 +111,7 @@ struct _GtkAssistantClass
 /**
  * GtkAssistantPageFunc:
  * @current_page: The page number used to calculate the next page.
- * @data: user data.
+ * @data: (closure): user data.
  *
  * A function used by gtk_assistant_set_forward_page_func() to know which
  * is the next page given a current one. It's called both for computing the
@@ -121,6 +124,8 @@ typedef gint (*GtkAssistantPageFunc) (gint current_page, gpointer data);
 
 GType                 gtk_assistant_get_type              (void) G_GNUC_CONST;
 GtkWidget            *gtk_assistant_new                   (void);
+void                  gtk_assistant_next_page             (GtkAssistant         *assistant);
+void                  gtk_assistant_previous_page         (GtkAssistant         *assistant);
 gint                  gtk_assistant_get_current_page      (GtkAssistant         *assistant);
 void                  gtk_assistant_set_current_page      (GtkAssistant         *assistant,
 							   gint                  page_num);
@@ -146,7 +151,7 @@ GtkAssistantPageType  gtk_assistant_get_page_type         (GtkAssistant
 void                  gtk_assistant_set_page_title        (GtkAssistant         *assistant,
 							   GtkWidget            *page,
 							   const gchar          *title);
-const gchar *         gtk_assistant_get_page_title        (GtkAssistant         *assistant,
+G_CONST_RETURN gchar *gtk_assistant_get_page_title        (GtkAssistant         *assistant,
 							   GtkWidget            *page);
 void                  gtk_assistant_set_page_header_image (GtkAssistant         *assistant,
 							   GtkWidget            *page,
